

from distutils.core import setup

from sensibleconfig import __doc__ as scdoc

setup(
    name='sensibleconfig',
    version='0.1',
    long_description=scdoc,
    author='Ali Afshar',
    author_email='aafshar@gmail.com',
    url='http://pidsoff.appspot.com/sensibleconfig',
)

